package canary

  1. Overview
  2. Docs

Module Notifier.GitlabSource

Notify failures to a GitLab project in the form of issues.

Parameters

module _ : GitlabConf

Signature

Sourceval notify : int notifier

notify ?search_params ?labels ~additional exn trace notify an unhandled exception to GitLab.

This reporter generates a digest of the exception message and trace. The issue will be titled as first 10 characters of digest | textual representation of exception. With a max length of 255 Each time the notifier is called, it searches GitLab for an exception whose title contains the first ten characters of the aforementioned digest. Each time the exception is caught, the notifier will comment with the additional information and add the labels passed.

search_params is an optional to pass e.g. `("state", "opened")` to only extend open issues

Sourceval connection_test : unit -> (unit, string) Lwt_result.t